#!/usr/bin/env python

# manifestops - Provides functions for performing different operations on a
# .manifest file
#
# Author: Kyle Nitzsche <kyle.nitzsche@canonical.com>
#
# Copyright (c) 20100 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
import sys
import datetime
import urllib2
import time
import os
from ConfigParser import RawConfigParser

def get_settings():
    SETTINGS_FILE = os.path.join(os.getcwd(), "config", "settings.conf")
    if not os.path.exists(SETTINGS_FILE):
        print "Error. Can't open " + SETTINGS_FILE + ". Stopping."
        sys.exit(1)

    config = RawConfigParser()
    config.read(SETTINGS_FILE)
    settings = dict()
    settings['distro_id'] = config.get('defaults', 'distro_id')
    settings['distro_codename'] = config.get('defaults', 'distro_codename')
    settings['distro_release'] = config.get('distros', settings['distro_codename'])
    settings['devel_milestone'] = config.get('defaults', 'devel_milestone')
    settings['product'] = config.get('defaults', 'product')
    settings['blacklist_priority'] = config.get('defaults', 'blacklist_priority')

    return settings

def get_working_pot_templates(settings):
    templates = os.path.join(os.getcwd(), 'data', settings['distro_codename'] + "-templates.txt")
    if not os.path.exists(templates):
        print >>sys.stderr, "Error: " + template + " file does not exist. Stopping."
        sys.exit(1)
    return templates

def get_http_timestamp(url):
    try:
        sock = urllib2.urlopen(url)
    except:
        return None

    print url

    timestamp_lm = None
    if sock.info()["Last-Modified"]:
        lm_string = sock.info()["Last-Modified"]
        print " >> lm_string: {0}".format(lm_string)
        sock.close()
        if lm_string:
            timestamp_lm = time.mktime(time.strptime(lm_string, "%a, %d %b %Y %H:%M:%S GMT"))
            print " >> timestamp_lm: {0}".format(timestamp_lm)
            datetime_lm = datetime.datetime.utcfromtimestamp(timestamp_lm)
            print " >> datetime_lm: {0}".format(datetime_lm)
            return datetime_lm
    return None

